# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/text2struct',
                'doc_host': 'https://bluegradients.github.io',
                'git_url': 'https://github.com/bluegradients/text2struct',
                'lib_path': 'text2struct'},
  'syms': { 'text2struct.core': { 'text2struct.core.OpenAIProvider': ('core.html#openaiprovider', 'text2struct/core.py'),
                                  'text2struct.core.OpenAIProvider.__call': ('core.html#openaiprovider.__call', 'text2struct/core.py'),
                                  'text2struct.core.OpenAIProvider.__init__': ('core.html#openaiprovider.__init__', 'text2struct/core.py'),
                                  'text2struct.core.OpenAIProvider.__parse_response': ( 'core.html#openaiprovider.__parse_response',
                                                                                        'text2struct/core.py'),
                                  'text2struct.core.OpenAIProvider.get_df': ('core.html#openaiprovider.get_df', 'text2struct/core.py'),
                                  'text2struct.core.OpenAIProvider.get_dict': ('core.html#openaiprovider.get_dict', 'text2struct/core.py'),
                                  'text2struct.core.OpenAIProvider.run': ('core.html#openaiprovider.run', 'text2struct/core.py'),
                                  'text2struct.core.Text2StructAbstract': ('core.html#text2structabstract', 'text2struct/core.py'),
                                  'text2struct.core.Text2StructAbstract.__init__': ( 'core.html#text2structabstract.__init__',
                                                                                     'text2struct/core.py'),
                                  'text2struct.core.Text2StructAbstract.get_df': ( 'core.html#text2structabstract.get_df',
                                                                                   'text2struct/core.py'),
                                  'text2struct.core.Text2StructAbstract.get_dict': ( 'core.html#text2structabstract.get_dict',
                                                                                     'text2struct/core.py'),
                                  'text2struct.core.Text2StructAbstract.run': ('core.html#text2structabstract.run', 'text2struct/core.py'),
                                  'text2struct.core.text2df': ('core.html#text2df', 'text2struct/core.py'),
                                  'text2struct.core.text2dict': ('core.html#text2dict', 'text2struct/core.py'),
                                  'text2struct.core.text2struct': ('core.html#text2struct', 'text2struct/core.py')}}}